Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1809)

Unified Diff: runtime/vm/flow_graph_compiler_mips.cc

Issue 70183010: Fixes a couple problems with GC of unoptimized code. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/flow_graph_compiler_mips.cc
===================================================================
--- runtime/vm/flow_graph_compiler_mips.cc (revision 30197)
+++ runtime/vm/flow_graph_compiler_mips.cc (working copy)
@@ -61,12 +61,12 @@
builder->MarkFrameStart();
// Current PP, FP, and PC.
- builder->AddPp(current->function(), slot_ix++);
+ builder->AddPp(current->code(), slot_ix++);
builder->AddCallerFp(slot_ix++);
- builder->AddReturnAddress(current->function(), deopt_id(), slot_ix++);
+ builder->AddReturnAddress(current->code(), deopt_id(), slot_ix++);
- // Callee's PC marker is not used anymore. Pass Function::null() to set to 0.
- builder->AddPcMarker(Function::Handle(), slot_ix++);
+ // Callee's PC marker is not used anymore. Pass Code::null() to set to 0.
+ builder->AddPcMarker(Code::Handle(), slot_ix++);
// Emit all values that are needed for materialization as a part of the
// expression stack for the bottom-most frame. This guarantees that GC
@@ -84,17 +84,17 @@
current = current->outer();
while (current != NULL) {
// PP, FP, and PC.
- builder->AddPp(current->function(), slot_ix++);
+ builder->AddPp(current->code(), slot_ix++);
builder->AddCallerFp(slot_ix++);
// For any outer environment the deopt id is that of the call instruction
// which is recorded in the outer environment.
- builder->AddReturnAddress(current->function(),
+ builder->AddReturnAddress(current->code(),
Isolate::ToDeoptAfter(current->deopt_id()),
slot_ix++);
// PC marker.
- builder->AddPcMarker(previous->function(), slot_ix++);
+ builder->AddPcMarker(previous->code(), slot_ix++);
// The values of outgoing arguments can be changed from the inlined call so
// we must read them from the previous environment.
@@ -126,7 +126,7 @@
builder->AddCallerPc(slot_ix++);
// PC marker.
- builder->AddPcMarker(previous->function(), slot_ix++);
+ builder->AddPcMarker(previous->code(), slot_ix++);
// For the outermost environment, set the incoming arguments.
for (intptr_t i = previous->fixed_parameter_count() - 1; i >= 0; i--) {

Powered by Google App Engine
This is Rietveld 408576698